@@ -57,7 +57,7 @@ def set_keychain(journal_name, password):
 
 def u(s):
     """Mock unicode function for python 2 and 3 compatibility."""
-    return s if PY3 or type(s) is unicode else unicode(s, "unicode_escape")
+    return s if PY3 or type(s) is unicode else unicode(s.encode('string-escape'), "unicode_escape")
 
 def prompt(msg):
     """Prints a message to the std err stream defined in util."""
@@ -65,10 +65,14 @@ def prompt(msg):
         msg += "\n"
     STDERR.write(u(msg))
 
-def py23_input(msg):
+def py23_input(msg=""):
     STDERR.write(u(msg))
     return STDIN.readline().strip()
 
+def py23_read(msg=""):
+    STDERR.write(u(msg))
+    return STDIN.read()
+
 def yesno(prompt, default=True):
     prompt = prompt.strip() + (" [Y/n]" if default else " [y/N]")
     raw = py23_input(prompt)
